.. include:: ../../README.rst

Features
--------

* Abstraction around the SystemCollection and System resources (Basic
  server identification and asset information)
* Systems power management (Both soft and hard; Including NMI injection)
* Changing systems boot device, frequency (Once or permanently) and mode
  (UEFI or BIOS)

Check out the :ref:`usage` page.

TODO
----

* Collect sensor data (Health state, temperature, fans etc...)
* System inspection (Number of CPUs, memory and disk size)
* Serial console
